# pygismeteo-base

[![CI](https://github.com/monosans/pygismeteo-base/actions/workflows/ci.yml/badge.svg?branch=main&event=push)](https://github.com/monosans/pygismeteo-base/actions/workflows/ci.yml)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/monosans/pygismeteo-base/main.svg)](https://results.pre-commit.ci/latest/github/monosans/pygismeteo-base/main)

База для [pygismeteo](https://github.com/monosans/pygismeteo) и [aiopygismeteo](https://github.com/monosans/aiopygismeteo).

## License / Лицензия

[MIT](https://github.com/monosans/pygismeteo-base/blob/main/LICENSE)
